Improve Patrole config options

- Renames "rbac_flag" to "enable_rbac"
- Creates "strict_policy_check" option
- Resolves bug where policy not in policy.json
  would pass RBAC test, leading to false test
  results

Change-Id: I76429e6cb0ed4cad154a07b7a873fd23209da674
Closes-Bug: #1673626
diff --git a/contrib/post_test_hook.sh b/contrib/post_test_hook.sh
index aeb4013..2eb494f 100644
--- a/contrib/post_test_hook.sh
+++ b/contrib/post_test_hook.sh
@@ -53,10 +53,12 @@
 # a "fast' or "slow test" gate
 TYPE=$2
 
-# Set rbac_flag=True under [rbac] section in tempest.conf
-iniset $TEMPEST_CONFIG rbac rbac_flag True
+# Set enable_rbac=True under [rbac] section in tempest.conf
+iniset $TEMPEST_CONFIG rbac enable_rbac True
 # Set rbac_test_role=$RBAC_ROLE under [rbac] section in tempest.conf
 iniset $TEMPEST_CONFIG rbac rbac_test_role $RBAC_ROLE
+# Set strict_policy_check=False under [rbac] section in tempest.conf
+iniset $TEMPEST_CONFIG rbac strict_policy_check False
 # Set additional, necessary CONF values
 iniset $TEMPEST_CONFIG auth use_dynamic_credentials True
 iniset $TEMPEST_CONFIG auth tempest_roles Member